# Please keep this package sync with FC

%global toolchain clang

# this stop us generating an empty debuginfo
%global debug_package %{nil}

%global shortname clc
%global libclc_version 19.1.7
#global rc_ver 4
%global libclc_srcdir libclc-%{libclc_version}%{?rc_ver:-rc%{rc_ver}}.src

Name:           libclc
Version:        %{libclc_version}%{?rc_ver:~rc%{rc_ver}}
Release:        %mkrel 1
Summary:        An open source implementation of the OpenCL 1.1 library requirements
Group:          Development/C

License:        Apache-2.0 WITH LLVM-exception OR NCSA OR MIT
URL:            https://libclc.llvm.org
Source0:        https://github.com/llvm/llvm-project/releases/download/llvmorg-%{libclc_version}%{?rc_ver:-rc%{rc_ver}}/%{libclc_srcdir}.tar.xz
Source1:        https://github.com/llvm/llvm-project/releases/download/llvmorg-%{libclc_version}%{?rc_ver:-rc%{rc_ver}}/%{libclc_srcdir}.tar.xz.sig
Source2:        release-keys.asc

BuildRequires:  clang-devel >= %{version}
BuildRequires:  libedit-devel
BuildRequires:  llvm-devel >= %{version}
BuildRequires:  python3
BuildRequires:  zlib-devel
BuildRequires:  cmake
BuildRequires:  spirv-llvm-translator-tools

# For signature verification
BuildRequires:  gnupg2

Requires:       %{name}-spirv%{?_isa} = %{version}-%{release}

%description
libclc is an open source, BSD licensed implementation of the library
requirements of the OpenCL C programming language, as specified by the
OpenCL 1.1 Specification. The following sections of the specification
impose library requirements:

  * 6.1: Supported Data Types
  * 6.2.3: Explicit Conversions
  * 6.2.4.2: Reinterpreting Types Using as_type() and as_typen()
  * 6.9: Preprocessor Directives and Macros
  * 6.11: Built-in Functionsj
  * 9.3: Double Precision Floating-Point
  * 9.4: 64-bit Atomics
  * 9.5: Writing to 3D image memory objects
  * 9.6: Half Precision Floating-Point

libclc is intended to be used with the Clang compiler's OpenCL frontend.

libclc is designed to be portable and extensible. To this end, it provides
generic implementations of most library requirements, allowing the target
to override the generic implementation at the granularity of individual
functions.

libclc currently only supports the PTX target, but support for more
targets is welcome.


%package        spirv
Summary:        Spirv subset of %{name}

%description    spirv
The %{name}-spirv package contains the spirv*-mesa3d-.spv files only,
which are the subset required for upstream Mesa OpenCL support with RustiCL.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%autosetup -n %{libclc_srcdir} -p2

%build
export CFLAGS="%{build_cflags} -D__extern_always_inline=inline"
%set_build_flags
%cmake -DCMAKE_INSTALL_DATADIR:PATH=%{_lib}

%cmake_build

%install
%cmake_install

%check
# external-calls-clspv--.bc test fails
%cmake_build --target test || true

%files
%license LICENSE.TXT
%doc README.TXT CREDITS.TXT
%dir %{_libdir}/%{shortname}
%{_libdir}/%{shortname}/*.bc

%files spirv
%license LICENSE.TXT
%doc README.TXT CREDITS.TXT
%dir %{_libdir}/%{shortname}
%{_libdir}/%{shortname}/spirv-mesa3d-.spv
%{_libdir}/%{shortname}/spirv64-mesa3d-.spv

%files devel
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/%{shortname}


%changelog
* Fri Apr 18 2025 wally <wally> 19.1.7-1.mga10
+ Revision: 2176818
- new version 19.1.7

* Sat Nov 16 2024 wally <wally> 19.1.3-1.mga10
+ Revision: 2116084
- new version 19.1.3

* Sun Feb 25 2024 wally <wally> 17.0.6-1.mga10
+ Revision: 2044256
- new version 17.0.6 (sync with Fedora)

* Thu Dec 08 2022 tv <tv> 15.0.6-1.mga9
+ Revision: 1919230
- Update to LLVM 15.0.6

* Tue Nov 15 2022 tv <tv> 15.0.4-1.mga9
+ Revision: 1907456
- Update to LLVM 15.0.4
- spirv-tools isn't needed

* Wed Sep 21 2022 tv <tv> 15.0.0-1.mga9
+ Revision: 1891262
- Update to LLVM 14.0.5

* Fri Jun 17 2022 tv <tv> 14.0.5-1.mga9
+ Revision: 1864665
- Update to LLVM 14.0.5

* Fri Apr 01 2022 umeabot <umeabot> 14.0.0-2.mga9
+ Revision: 1838153
- Mageia 9 Mass Rebuild

* Wed Mar 30 2022 tv <tv> 14.0.0-1.mga9
+ Revision: 1834554
- Update to LLVM 14.0.0

* Thu Feb 03 2022 tv <tv> 13.0.1-1.mga9
+ Revision: 1771240
- Update to 13.0.1 final

* Fri Oct 22 2021 tv <tv> 13.0.0-2.mga9
+ Revision: 1752636
- 13.0.0 Release

* Mon Apr 19 2021 tv <tv> 12.0.0-2.mga9
+ Revision: 1716947
- Run testsuite
- list targets to build

* Sat Apr 17 2021 daviddavid <daviddavid> 12.0.0-1.mga9
+ Revision: 1716246
- new version: 12.0.0 final

* Wed Apr 07 2021 tmb <tmb> 12.0.0-0.rc4.1.mga9
+ Revision: 1714014
- fix previous BR, its spirv-llvm-translator-tools
- update to rc4
- BR: spirv-llvm-translator
- fix pkgconfig libexecdir (mga#28738)
+ daviddavid <daviddavid>
- new version: 12.0.0-rc3

* Sun Feb 28 2021 tv <tv> 11.0.0-1.mga9
+ Revision: 1693223
- Latest upstream release that matches llvm 11.0.0

* Mon Feb 01 2021 tmb <tmb> 0.2.0-6.mga8
+ Revision: 1674325
- update to release tarball from llvm 11.0.1 branch (mga#27993)

* Sat May 23 2020 wally <wally> 0.2.0-4.mga8
+ Revision: 1587082
- build with python3

* Sat Feb 15 2020 umeabot <umeabot> 0.2.0-3.mga8
+ Revision: 1525405
- Mageia 8 Mass Rebuild

* Tue Apr 16 2019 daviddavid <daviddavid> 0.2.0-2.mga7
+ Revision: 1391150
- rebuild for new llvm/clang 8.0

* Wed Mar 20 2019 tv <tv> 0.2.0-1.mga7
+ Revision: 1379306
- imported package libclc


* Wed Mar 20 2019 Thierry Vignaud <tv@mageia.org> 0.2.0-1.mga7
- import from FC

* Tue Dec 04 2018 Dave Airlie <airlied@redhat.com> - 0.2.0-13.git1ecb16d
- Update to latest libclc snapshot

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.2.0-12.gitc45b9df
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Mon Jul 09 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 0.2.0-11.gitc45b9df
- Update to latest git snapshot

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.2.0-10.git1cb3fbf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Aug 02 2017 Dan Horák <dan[at]danny.cz> - 0.2.0-9.git1cb3fbf
- Drop build workarounds

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.2.0-8.git1cb3fbf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon Jul 24 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 0.2.0-7.git1cb3fbf
- Update to latest git snapshot

* Sat Mar 11 2017 Igor Gnatenko <ignatenko@redhat.com> - 0.2.0-6.git520743b
- Update to latest snapshot which supports LLVM 3.9

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.2.0-5.20160207gitdc330a3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Aug 10 2016 Dan Horák <dan[at]danny.cz> - 0.2.0-4.20160207gitdc330a3
- Build on s390x

* Sun Apr 10 2016 Peter Robinson <pbrobinson@fedoraproject.org> 0.2.0-3.20160207gitdc330a3
- Build on ARMv7

* Tue Apr 05 2016 Than Ngo <than@redhat.com> - 0.2.0-2.20160207gitdc330a3
- temporary disable stack-protector on powe64 as workaround due to the bug in llvm
  which causes the build failure on power64

* Sun Feb 07 2016 Fabian Deutsch <fabiand@fedoraproject.org> - 0.2.0-1.20160207gitdc330a3
- Update to latest upstream
- Dorp llvm-static BR

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.0.1-14.20150918git4346c30
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Jan 21 2016 Peter Robinson <pbrobinson@fedoraproject.org> 0.0.1-13.20150918git4346c30
- Spell aarch64 correctly

* Thu Jan 21 2016 Peter Robinson <pbrobinson@fedoraproject.org> 0.0.1-12.20150918git4346c30
- Now supported on aarch64/Power64

* Fri Sep 18 2015 Dave Airlie <airlied@redhat.com> 0.0.1-11.20150918git4346c30
- latest snapshot - set build req to llvm 3.7

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.1-10.20140901gite822ae3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Jan 08 2015 Adel Gadllah <adel.gadllah@gmail.com> - 0.0.1-9.20140901gite822ae3
- Rebuilt with newer llvm

* Tue Oct 28 2014 Peter Robinson <pbrobinson@fedoraproject.org> - 0.0.1-8.20140901gite822ae3
- Update to a newer snapshot

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.1-7.20140705git61127c5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Fri Jul 25 2014 Peter Robinson <pbrobinson@fedoraproject.org> 0.0.1-6
- Rebuild now llvm bits are fixed for gcc-4.9
- Minor cleanups

* Sat Jul 05 2014 Fabian Deutsch <fabiand@fedoraproject.org> - 0.0.1-5
- Update to latest snapshot to support AMD Kaveri APUs
- Move bitcode files to an arch dependent dir, as they are arch dependent

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.1-4.20140429git4341094
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Apr 29 2014 Fabian Deutsch <fabiand@fedoraproject.org> - 0.0.1-2.20140429git4341094
- Update to latest snapshot
- Support for AMD Kabini

* Mon Jan 13 2014 Fabian Deutsch <fabiand@fedoraproject.org> - 0.0.1-2.20140108gitc002f62
- Move headers to main package, needed by clover at runtime

* Wed Jan 08 2014 Fabian Deutsch <fabiand@fedoraproject.org> - 0.0.1-1.20140108gitc002f62
- Could not use latest master because it doesn't build
- Update to a fresher snapshot
- Limit to x86

* Sun Jul 14 2013 Fabian Deutsch <fabiand@fedoraproject.org> - 0.0.1-0.20130714git5217211
- Initial package
